supported_data_formats = [
  'csv',
  'json',
  'parquet',
  'pkl',
  'xlsx',
]

supported_img_formats = [] # TODO: add supported image formats

supported_doc_formats = [] # TODO: add supported document formats